==> hibiscus.js-1.2.1.tgz: package/http/http.service.js <==
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';
import { HttpParams, HttpHeaders, HttpEventType, HttpErrorResponse, } from '@angular/common/http';
function isObject(value) {
    return value !== null && typeof value === 'object';
}
function isUndefined(value) {
    return typeof value === 'undefined';
}
function isEmpty(value) {
    return typeof value === 'undefined' || value === null;
}
var HttpProvider = /** @class */ (function () {
    function HttpProvider() {
        this.interceptors = [];
    }
    HttpProvider.prototype.getInterceptors = function () {
        return this.interceptors;
    };
    HttpProvider.prototype.addInterceptor = function (interceptor) {
        this.interceptors.push(interceptor);
        return this;
    };
    HttpProvider.prototype.addRequestInterceptor = function (interceptor) {
        return this.addInterceptor({
            request: function (request) {
                return interceptor(request) || request;
            }
        });
    };
    HttpProvider.prototype.addResponseInterceptor = function (interceptor) {
        return this.addInterceptor({
            response: function (response, request) {
                return interceptor(response, request) || response;
            }
        });
    };
    HttpProvider.prototype.addResponseErrorInterceptor = function (interceptor) {
        return this.addInterceptor({
            response: function (response, request) {
                if (response instanceof HttpErrorResponse) {
                    return interceptor(response, request) || response;
                }
            }
        });
    };
    HttpProvider.prototype.handleRequest = function (req) {
        return this.interceptors
            .filter(function (item) { return !!item.request; })
            .reduce(function (httpEvent, item) {
            return (item.request(httpEvent) || httpEvent);
        }, req);
    };
    HttpProvider.prototype.handleResponse = function (response, request) {
        return this.interceptors
            .filter(function (item) { return !!item.response; })
            .reverse()
            .reduce(function (httpEvent, item) {
            return item.response(httpEvent, request) || httpEvent;
        }, response);
    };
    HttpProvider.prototype.baseUrl = function (host, excludes) {
        if (excludes === void 0) { excludes = []; }
        this.interceptors.push({
            request: function (request) {
                if (/^https?:/.test(request.url)) {
                    return request;
                }
                var excludeUrl = excludes.some(function (t) { return t.test(request.url); });
                if (excludeUrl) {
                    return request;
                }
                host = host.replace(/\/$/, '');
                var url = request.url.replace(/^\//, '');
                return request.clone({ url: host + "/" + url });
            }
        });
        return this;
    };
    HttpProvider.prototype.headers = function (headers) {
        if (headers === void 0) { headers = {}; }
        return this.addInterceptor({
            request: function (request) {
                return request.clone({ setHeaders: headers });
            }
        });
    };
    HttpProvider.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    HttpProvider.ctorParameters = function () { return []; };
    return HttpProvider;
}());
export { HttpProvider };
var HttpInterceptors = /** @class */ (function () {
    function HttpInterceptors(httpProvider) {
        this.httpProvider = httpProvider;
    }
    HttpInterceptors.prototype.intercept = function (req, next) {
        var _this = this;
        var httpRequest = this.httpProvider.handleRequest(req);
        return next.handle(httpRequest)
            .map(function (response) {
            if ([HttpEventType.Response, HttpEventType.ResponseHeader].indexOf(response.type) !== -1) {
                return (_this.httpProvider.handleResponse(response, httpRequest) || response);
            }
            return response;
        })
            .catch(function (error) { return Observable.throw(_this.httpProvider.handleResponse(error, httpRequest) || error); });
    };
    HttpInterceptors.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    HttpInterceptors.ctorParameters = function () { return [
        { type: HttpProvider, },
    ]; };
    return HttpInterceptors;
}());
export { HttpInterceptors };
var Httpd = /** @class */ (function () {
    function Httpd(http) {
        this.http = http;
    }
    Httpd.prototype.getBaseUrl = function () {
        return null;
    };
    Httpd.prototype.getHeaders = function () {
        return null;
    };
    Httpd.prototype.setBaseUrl = function (url) {
        return this.getBaseUrl = function () {
            return url;
        };
    };
    Httpd.prototype.setHeaders = function (headers) {
        return this.getHeaders = function () {
            return headers;
        };
    };
    return Httpd;
}());
export { Httpd };
/**
 * Set the base URL of http resource
 * @param {String} url - base URL
 */
export function BaseUrl(url) {
    return function (target) {
        target.prototype.getBaseUrl = function () {
            return url;
        };
        return target;
    };
}
/**
 * Set default headers for every method of the RESTClient
 * @param {Object} headers - deafult headers in a key-value pair
 */
export function Headers(headers) {
    return function (target) {
        target.prototype.getHeaders = function () {
            return headers;
        };
        return target;
    };
}
function paramBuilder(paramName, optional) {
    if (optional === void 0) { optional = false; }
    return function (key) {
        if (!optional && !key) {
            throw new Error(paramName + " Key is required!");
        }
        return function (target, propertyKey, parameterIndex) {
            var metadataKey = propertyKey + "_" + paramName + "_parameters";
            var paramObj = {
                key: key,
                parameterIndex: parameterIndex
            };
            if (Array.isArray(target[metadataKey])) {
                target[metadataKey].push(paramObj);
            }
            else {
                target[metadataKey] = [paramObj];
            }
        };
    };
}
/**
 * Path variable of a method's url, type: string
 * @param {string} key - path key to bind value
 */
export var Path = paramBuilder('Path');
/**
 * Query value of a method's url, type: string
 * @param {string} key - query key to bind value
 */
export var Query = paramBuilder('Query', true);
/**
 * Body of a REST method, type: key-value pair object
 * Only one body per method!
 */
export var Body = paramBuilder('Body')('Body');
/**
 * Custom header of a REST method, type: string
 * @param {string} key - header key to bind value
 */
export var Header = paramBuilder('Header');
export function RequestOptions(options) {
    return function (target, propertyKey, descriptor) {
        options.observe = options.observe || 'body';
        options.reportProgress = isUndefined(options.reportProgress) ? false : options.reportProgress;
        options.responseType = options.responseType || 'json';
        options.withCredentials = isUndefined(options.withCredentials) ? false : options.withCredentials;
        descriptor.requestOptions = options;
        return descriptor;
    };
}
function methodBuilder(method) {
    return function (url) {
        return function (target, propertyKey, descriptor) {
            var pPath = target[propertyKey + "_Path_parameters"];
            var pQuery = target[propertyKey + "_Query_parameters"];
            var pBody = target[propertyKey + "_Body_parameters"];
            var pHeader = target[propertyKey + "_Header_parameters"];
            var oldDescriptor = descriptor.value;
            descriptor.value = function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                // call method for test coverage
                try {
                    oldDescriptor.apply(this, args);
                }
                catch (e) {
                    e.toString();
                }
                // Body
                var body = '';
                if (pBody) {
                    body = args[pBody[0].parameterIndex];
                }
                // Path
                var resUrl = url;
                if (pPath) {
                    for (var k in pPath) {
                        if (pPath.hasOwnProperty(k)) {
                            resUrl = resUrl.replace(":" + pPath[k].key, encodeURIComponent(args[pPath[k].parameterIndex]));
                        }
                    }
                }
                // Query
                var params = new HttpParams();
                if (pQuery) {
                    params = pQuery
                        .filter(function (p) { return !isUndefined(args[p.parameterIndex]); })
                        .reduce(function (ps, p) {
                        var key = p.key;
                        var value = args[p.parameterIndex];
                        var result = ps;
                        if (value instanceof Date) {
                            result = result.set(key, value.getTime().toString());
                        }
                        else if (Array.isArray(value)) {
                            result = result.set(key, value.map(function (item) { return item; }).join(','));
                        }
                        else if (isObject(value)) {
                            for (var k in value) {
                                if (value.hasOwnProperty(k) && !isUndefined(value[k])) {
                                    result = result.set(k, value[k]);
                                }
                            }
                        }
                        else if (!isEmpty(value)) {
                            result = result.set(key, value.toString());
                        }
                        else {
                            result = result.set(key, '');
                        }
                        return result;
                    }, params);
                }
                // Headers
                // set class default headers
                var headers = new HttpHeaders(this.getHeaders());
                // set method specific headers
                for (var k in descriptor.headers) {
                    if (descriptor.headers.hasOwnProperty(k)) {
                        headers = headers.append(k, descriptor.headers[k]);
                    }
                }
                if (pHeader) {
                    for (var k in pHeader) {
                        if (pHeader.hasOwnProperty(k)) {
                            headers = headers.append(pHeader[k].key, args[pHeader[k].parameterIndex]);
                        }
                    }
                }
                var baseUrl = this.getBaseUrl();
                var host = baseUrl ? baseUrl.replace(/\/$/, '') + '/' : '';
                var requestUrl = "" + host + resUrl.replace(/^\//, '');
                var defaultOptions = descriptor.requestOptions;
                if (defaultOptions) {
                    var headerKeys = defaultOptions.headers ? defaultOptions.headers.keys() : [];
                    for (var i = 0; i < headerKeys.length; i++) {
                        var k = headerKeys[i];
                        headers = headers.append(k, defaultOptions.headers.get(k));
                    }
                    var paramKeys = defaultOptions.params ? defaultOptions.params.keys() : [];
                    for (var i = 0; i < paramKeys.length; i++) {
                        var k = paramKeys[i];
                        params = params.append(k, defaultOptions.params.get(k));
                    }
                }
                var options = {
                    body: body,
                    headers: headers,
                    params: params,
                    observe: defaultOptions ? defaultOptions.observe : 'body',
                    reportProgress: defaultOptions ? defaultOptions.reportProgress : false,
                    responseType: defaultOptions ? defaultOptions.responseType : 'json',
                    withCredentials: defaultOptions ? defaultOptions.withCredentials : false
                };
                return this.http.request(method, requestUrl, options);
            };
            return descriptor;
        };
    };
}
/**
 * GET method
 * @param {string} url - resource url of the method
 */
export var GET = methodBuilder('GET');
/**
 * JSONP method
 * @param {string} url - resource url of the method
 */
export var JSONP = methodBuilder('JSONP');
/**
 * POST method
 * @param {string} url - resource url of the method
 */
export var POST = methodBuilder('POST');
/**
 * PUT method
 * @param {string} url - resource url of the method
 */
export var PUT = methodBuilder('PUT');
/**
 * DELETE method
 * @param {string} url - resource url of the method
 */
export var DELETE = methodBuilder('DELETE');
/**
 * HEAD method
 * @param {string} url - resource url of the method
 */
export var HEAD = methodBuilder('HEAD');
/**
 * PATCH method
 * @param {string} url - resource url of the method
 */
export var PATCH = methodBuilder('PATCH');
/**
 * OPTIONS method
 * @param {string} url - resource url of the method
 */
export var OPTIONS = methodBuilder('OPTIONS');
export var HTTP_PROVIDERS = [
    HttpProvider
];

==> hibiscus.js-1.2.3.tgz: package/http/http.service.js <==
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs/Observable';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/catch';
import 'rxjs/add/observable/throw';
import { HttpParams, HttpHeaders, HttpEventType, HttpErrorResponse, } from '@angular/common/http';
function isObject(value) {
    return value !== null && typeof value === 'object';
}
function isUndefined(value) {
    return typeof value === 'undefined';
}
function isEmpty(value) {
    return typeof value === 'undefined' || value === null;
}
var HttpProvider = (function () {
    function HttpProvider() {
        this.interceptors = [];
    }
    HttpProvider.prototype.getInterceptors = function () {
        return this.interceptors;
    };
    HttpProvider.prototype.addInterceptor = function (interceptor) {
        this.interceptors.push(interceptor);
        return this;
    };
    HttpProvider.prototype.addRequestInterceptor = function (interceptor) {
        return this.addInterceptor({
            request: function (request) {
                return interceptor(request) || request;
            }
        });
    };
    HttpProvider.prototype.addResponseInterceptor = function (interceptor) {
        return this.addInterceptor({
            response: function (response, request) {
                return interceptor(response, request) || response;
            }
        });
    };
    HttpProvider.prototype.addResponseErrorInterceptor = function (interceptor) {
        return this.addInterceptor({
            response: function (response, request) {
                if (response instanceof HttpErrorResponse) {
                    return interceptor(response, request) || response;
                }
            }
        });
    };
    HttpProvider.prototype.handleRequest = function (req) {
        return this.interceptors
            .filter(function (item) { return !!item.request; })
            .reduce(function (httpEvent, item) {
            return (item.request(httpEvent) || httpEvent);
        }, req);
    };
    HttpProvider.prototype.handleResponse = function (response, request) {
        return this.interceptors
            .filter(function (item) { return !!item.response; })
            .reverse()
            .reduce(function (httpEvent, item) {
            return item.response(httpEvent, request) || httpEvent;
        }, response);
    };
    HttpProvider.prototype.baseUrl = function (host, excludes) {
        if (excludes === void 0) { excludes = []; }
        this.interceptors.push({
            request: function (request) {
                if (/^https?:/.test(request.url)) {
                    return request;
                }
                var excludeUrl = excludes.some(function (t) { return t.test(request.url); });
                if (excludeUrl) {
                    return request;
                }
                host = host.replace(/\/$/, '');
                var url = request.url.replace(/^\//, '');
                return request.clone({ url: host + "/" + url });
            }
        });
        return this;
    };
    HttpProvider.prototype.headers = function (headers) {
        if (headers === void 0) { headers = {}; }
        return this.addInterceptor({
            request: function (request) {
                return request.clone({ setHeaders: headers });
            }
        });
    };
    HttpProvider.decorators = [
        { type: Injectable },
    ];
    HttpProvider.ctorParameters = function () { return []; };
    return HttpProvider;
}());
export { HttpProvider };
var HttpInterceptors = (function () {
    function HttpInterceptors(httpProvider) {
        this.httpProvider = httpProvider;
    }
    HttpInterceptors.prototype.intercept = function (req, next) {
        var _this = this;
        var httpRequest = this.httpProvider.handleRequest(req);
        return next.handle(httpRequest)
            .map(function (response) {
            if ([HttpEventType.Response, HttpEventType.ResponseHeader].indexOf(response.type) !== -1) {
                return (_this.httpProvider.handleResponse(response, httpRequest) || response);
            }
            return response;
        })
            .catch(function (error) { return Observable.throw(_this.httpProvider.handleResponse(error, httpRequest) || error); });
    };
    HttpInterceptors.decorators = [
        { type: Injectable },
    ];
    HttpInterceptors.ctorParameters = function () { return [
        { type: HttpProvider, },
    ]; };
    return HttpInterceptors;
}());
export { HttpInterceptors };
var Httpd = (function () {
    function Httpd(http) {
        this.http = http;
    }
    Httpd.prototype.getBaseUrl = function () {
        return null;
    };
    Httpd.prototype.getHeaders = function () {
        return null;
    };
    Httpd.prototype.setBaseUrl = function (url) {
        return this.getBaseUrl = function () {
            return url;
        };
    };
    Httpd.prototype.setHeaders = function (headers) {
        return this.getHeaders = function () {
            return headers;
        };
    };
    return Httpd;
}());
export { Httpd };
export function BaseUrl(url) {
    return function (target) {
        target.prototype.getBaseUrl = function () {
            return url;
        };
        return target;
    };
}
export function Headers(headers) {
    return function (target) {
        target.prototype.getHeaders = function () {
            return headers;
        };
        return target;
    };
}
function paramBuilder(paramName, optional) {
    if (optional === void 0) { optional = false; }
    return function (key) {
        if (!optional && !key) {
            throw new Error(paramName + " Key is required!");
        }
        return function (target, propertyKey, parameterIndex) {
            var metadataKey = propertyKey + "_" + paramName + "_parameters";
            var paramObj = {
                key: key,
                parameterIndex: parameterIndex
            };
            if (Array.isArray(target[metadataKey])) {
                target[metadataKey].push(paramObj);
            }
            else {
                target[metadataKey] = [paramObj];
            }
        };
    };
}
export var Path = paramBuilder('Path');
export var Query = paramBuilder('Query', true);
export var Body = paramBuilder('Body')('Body');
export var Header = paramBuilder('Header');
export function RequestOptions(options) {
    return function (target, propertyKey, descriptor) {
        options.observe = options.observe || 'body';
        options.reportProgress = isUndefined(options.reportProgress) ? false : options.reportProgress;
        options.responseType = options.responseType || 'json';
        options.withCredentials = isUndefined(options.withCredentials) ? false : options.withCredentials;
        descriptor.requestOptions = options;
        return descriptor;
    };
}
function methodBuilder(method) {
    return function (url) {
        return function (target, propertyKey, descriptor) {
            var pPath = target[propertyKey + "_Path_parameters"];
            var pQuery = target[propertyKey + "_Query_parameters"];
            var pBody = target[propertyKey + "_Body_parameters"];
            var pHeader = target[propertyKey + "_Header_parameters"];
            var oldDescriptor = descriptor.value;
            descriptor.value = function () {
                var args = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    args[_i] = arguments[_i];
                }
                try {
                    oldDescriptor.apply(this, args);
                }
                catch (e) {
                    e.toString();
                }
                var body = '';
                if (pBody) {
                    body = args[pBody[0].parameterIndex];
                }
                var resUrl = url;
                if (pPath) {
                    for (var k in pPath) {
                        if (pPath.hasOwnProperty(k)) {
                            resUrl = resUrl.replace(":" + pPath[k].key, encodeURIComponent(args[pPath[k].parameterIndex]));
                        }
                    }
                }
                var params = new HttpParams();
                if (pQuery) {
                    params = pQuery
                        .filter(function (p) { return !isUndefined(args[p.parameterIndex]); })
                        .reduce(function (ps, p) {
                        var key = p.key;
                        var value = args[p.parameterIndex];
                        var result = ps;
                        if (value instanceof Date) {
                            result = result.set(key, value.getTime().toString());
                        }
                        else if (Array.isArray(value)) {
                            result = result.set(key, value.map(function (item) { return item; }).join(','));
                        }
                        else if (isObject(value)) {
                            for (var k in value) {
                                if (value.hasOwnProperty(k) && !isUndefined(value[k])) {
                                    result = result.set(k, value[k]);
                                }
                            }
                        }
                        else if (!isEmpty(value)) {
                            result = result.set(key, value.toString());
                        }
                        else {
                            result = result.set(key, '');
                        }
                        return result;
                    }, params);
                }
                var headers = new HttpHeaders(this.getHeaders());
                for (var k in descriptor.headers) {
                    if (descriptor.headers.hasOwnProperty(k)) {
                        headers = headers.append(k, descriptor.headers[k]);
                    }
                }
                if (pHeader) {
                    for (var k in pHeader) {
                        if (pHeader.hasOwnProperty(k)) {
                            headers = headers.append(pHeader[k].key, args[pHeader[k].parameterIndex]);
                        }
                    }
                }
                var baseUrl = this.getBaseUrl();
                var host = baseUrl ? baseUrl.replace(/\/$/, '') + '/' : '';
                var requestUrl = "" + host + resUrl.replace(/^\//, '');
                var defaultOptions = descriptor.requestOptions;
                if (defaultOptions) {
                    var headerKeys = defaultOptions.headers ? defaultOptions.headers.keys() : [];
                    for (var i = 0; i < headerKeys.length; i++) {
                        var k = headerKeys[i];
                        headers = headers.append(k, defaultOptions.headers.get(k));
                    }
                    var paramKeys = defaultOptions.params ? defaultOptions.params.keys() : [];
                    for (var i = 0; i < paramKeys.length; i++) {
                        var k = paramKeys[i];
                        params = params.append(k, defaultOptions.params.get(k));
                    }
                }
                var options = {
                    body: body,
                    headers: headers,
                    params: params,
                    observe: defaultOptions ? defaultOptions.observe : 'body',
                    reportProgress: defaultOptions ? defaultOptions.reportProgress : false,
                    responseType: defaultOptions ? defaultOptions.responseType : 'json',
                    withCredentials: defaultOptions ? defaultOptions.withCredentials : false
                };
                return this.http.request(method, requestUrl, options);
            };
            return descriptor;
        };
    };
}
export var GET = methodBuilder('GET');
export var JSONP = methodBuilder('JSONP');
export var POST = methodBuilder('POST');
export var PUT = methodBuilder('PUT');
export var DELETE = methodBuilder('DELETE');
export var HEAD = methodBuilder('HEAD');
export var PATCH = methodBuilder('PATCH');
export var OPTIONS = methodBuilder('OPTIONS');
export var HTTP_PROVIDERS = [
    HttpProvider
];
